@@ -97,6 +97,8 @@ const	AI	*next_addr;		/* The next one to try upon failure */
 	SS	local_sockname; 	/* sockname of this connection */
 	SS	remote_sockname; 	/* sockname of this connection */
 	SS	uh_addr;		/* ip address the server sees */
+	int	uh_addr_set;		/* 0 or 1, if set_uh_addr() has been called */
+					/* Used to guard an annoying error message */
 	NotifyList	notify_list;	/* Notify list for this server */
 	char 	*cookie;		/* Erf/TS4 "cookie" value */
 	int	line_length;		/* How long a protocol command may be */
@@ -188,11 +190,11 @@ static __inline__ Server *	get_server (int server)
 #define FROMSERV	-1
 
 /* Funny stuff */
-#define FUNNY_PUBLIC            1 << 0
-#define FUNNY_PRIVATE           1 << 1
-#define FUNNY_TOPIC             1 << 2
-#define FUNNY_USERS             1 << 4
-#define FUNNY_NAME              1 << 5
+#define FUNNY_PUBLIC	(1 << 0)
+#define FUNNY_PRIVATE	(1 << 1)
+#define FUNNY_TOPIC	(1 << 2)
+#define FUNNY_USERS	(1 << 4)
+#define FUNNY_NAME	(1 << 5)
 
 #define SERVER_CREATED		0
 #define SERVER_RECONNECT	1
