@@ -131,6 +131,8 @@ int	ALLOW_C1_CHARS_VAR,
 	STATUS_NO_REPEAT_VAR,
 	STATUS_OPER_VAR,
 	STATUS_OVERWRITE_VAR,
+	STATUS_PREFIX_WHEN_CURRENT_VAR,
+	STATUS_PREFIX_WHEN_NOT_CURRENT_VAR,
 	STATUS_QUERY_VAR,
 	STATUS_SCROLLBACK_VAR,
 	STATUS_SERVER_VAR,
@@ -235,6 +237,7 @@ typedef struct
 	void	init_variables_stage1	(void);
 	void	init_variables_stage2	(void);
 	char*	make_string_var 	(const char *);
+	int     make_string_var2 	(const char *, char **);
 	int	charset_size 		(void);
 	void	save_variables 		(FILE *, int);
 	void	do_stack_set		(int, char *);
