@@ -39,19 +39,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC5-2.0.1";
-const char useful_info[] = "epic5 2 0 1";
+const char irc_version[] = "EPIC5-2.1.1";
+const char useful_info[] = "epic5 2 1 1";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20160805";
+const char internal_version[] = "20190224";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 1869;
+const unsigned long	commit_id = 1898;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -59,7 +59,7 @@ const unsigned long	commit_id = 1869;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Indolence";
+const char ridiculous_version_name[] = "Abulia";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -89,7 +89,12 @@ const char ridiculous_version_name[] = "Indolence";
 #include "levels.h"
 #include "extlang.h"
 #include "files.h"
+#include "ctcp.h"
 #include <pwd.h>
+#ifdef NEWLOCALE_REQUIRES__GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#include <locale.h>
 
 
 /*
@@ -838,8 +843,10 @@ static void	do_signals(void)
 	{
 		while (signals_caught[sig_no])
 		{
-			do_hook(SIGNAL_LIST, "%d %d", sig_no, 
-					signals_caught[sig_no]);
+			do_hook(SIGNAL_LIST, "%d %d", sig_no,
+				signals_caught[sig_no]);
+			do_hook(SIGNAL_LIST, "%s %d", get_signal_name(sig_no),
+				signals_caught[sig_no]);
 			signals_caught[sig_no]--;
 		}
 	}
@@ -1186,6 +1193,7 @@ int 	main (int argc, char *argv[])
 	init_functions();
 	init_expandos();
 	init_newio();
+	init_ctcp();
 
 	fprintf(stderr, "EPIC Version 5 -- %s\n", ridiculous_version_name);
 	fprintf(stderr, "EPIC Software Labs (2006)\n");
