@@ -60,7 +60,11 @@
 
 typedef	struct	myio_struct
 {
-	int	channel;		/* XXX Future expansion XXX */
+	/* 
+	 * On Unix, "Channel" means "fd".
+	 * On VMS, "Channel" is a random 32 bit int.
+	 */
+	int	channel;	
 	char *	buffer;
 	size_t	buffer_size,
 		read_pos,
@@ -71,6 +75,7 @@ typedef	struct	myio_struct
 		held;
 	void	(*callback) (int vfd);
 	int	(*io_callback) (int vfd, int quiet);
+	int	(*failure_callback) (int channel, int error);
 	int	quiet;
 	int	server;			/* For message routing */
 }           MyIO;
@@ -580,6 +585,7 @@ int 	new_open (int channel, void (*callback) (int), int io_type, int quiet, int
 		panic(1, "New_open doesn't recognize io type %d", io_type);
 
 	ioe->callback = callback;
+	ioe->failure_callback = NULL;
 
 	if (io_type == NEWIO_CONNECT)
 	{
@@ -606,6 +612,32 @@ int 	new_open (int channel, void (*callback) (int), int io_type, int quiet, int
 	return vfd;
 }
 
+/*
+ * On a VFD registered with new_open(), you may want a callback when the
+ * fd has gone bad, so you can do your own cleanup.
+ * This is intended for the Python support.
+ * 
+ * The callback provides two arguments:
+ *	1 - channel - the channel (fd) passed to new_open()
+ *	2 - error - this is reserved for future expansion
+ */
+int 	new_open_failure_callback (int channel, void (*failure_callback) (int, int))
+{
+	MyIO *	ioe;
+	int	vfd;
+
+	vfd = VFD(channel);
+	if (vfd >= 0 && vfd <= global_max_vfd && (ioe = io_rec[vfd]))
+	{
+		ioe->failure_callback = failure_callback;
+		return 0;
+	}
+
+	syserr(-1, "new_open_failure_callback: Called for Channel %d that is not set up", channel);
+	return -1;		/* Oh well. */
+}
+
+
 /*
  * This isn't really new, but what the hey..
  *
@@ -645,7 +677,7 @@ int	new_unhold_fd (int vfd)
  * Unregister a filedesc for readable events 
  * and close it down and free its input buffer
  */
-int	new_close (int vfd)
+int	new_close_with_option (int vfd, int virtual)
 {
 	MyIO *	ioe;
 
@@ -656,10 +688,17 @@ int	new_close (int vfd)
 	{
 		if (ioe->io_callback == ssl_read)	/* XXX */
 			ssl_shutdown(ioe->channel);
+
 		knoread(vfd);
 		knowrite(vfd);
 
-		unix_close(ioe->channel, ioe->quiet);
+		/* 
+		 * If virtual == 1, then the caller is managing the 
+		 * fd and must close(2) it themselves.
+		 * (ie, fd's from external languages)
+		 */
+		if (virtual == 0)
+			unix_close(ioe->channel, ioe->quiet);
 
 		new_free(&ioe->buffer); 
 		new_free((char **)&(io_rec[vfd]));
@@ -673,12 +712,37 @@ int	new_close (int vfd)
 		    while (global_max_vfd >= 0 && !io_rec[global_max_vfd])
 			global_max_vfd--;
 	}
-	else
+	else if (virtual == 0)
 		unix_close(vfd, 0);
 
 	return -1;
 }
 
+/* 
+ * The lower level IO functions call us when an channel (fd) is found dead,
+ * and has been untracked (FD_CLR) and unregistered (new_close()), so we
+ * may tell any owner of this.
+ */
+static	void	fd_is_invalid (int channel)
+{
+	int	vfd;
+	MyIO *	ioe;
+
+	vfd = VFD(channel);
+	if (vfd >= 0 && vfd <= global_max_vfd && (ioe = io_rec[vfd]))
+	{
+		if (ioe->failure_callback)
+			ioe->failure_callback(channel, 0);
+	}
+	else
+	{
+		syserr(-1, "fd_is_invalid called on unsetup channel %d", channel);
+		return;
+	}
+
+
+}
+
 
 /***********************************************************************/
 /******************** Start of unix-specific code here ******************/
@@ -849,9 +913,19 @@ static int	unix_connect (int channel, int quiet)
 
 
 /*
- * Perform a synchronous i/o operation on a file descriptor.  This should
- * result in a call to dgets_buffer() (c > 0) or some sort of error condition
- * (c <= 0).
+ * Perform a synchronous i/o operation on a file descriptor.  
+ * This function is called by kdoit(), which is called by do_wait().
+ *
+ * The way I/O works in EPIC:
+ *	+ main loop calls do_wait()
+ *	  + do_wait() calls kdoit() [there are several of these]
+ *	  + If kdoit() decides an fd is ready, it looks at all fd's
+ *		and for any fd's that are "ready", calls new_io_event().
+ *	    + new_io_event() [us] does an I/O operation and queues up some
+ *		data using dgets_buffer(), and marks the fd as "dirty"
+ *	+ main loop calls do_filedesc() is called, and that calls the 
+ *		user's callback, which uses dgets() to return 
+ *		whatever was queued up here, and marks the fd as "clean".
  */
 static void	new_io_event (int vfd)
 {
@@ -865,20 +939,54 @@ static void	new_io_event (int vfd)
 	if (!ioe->clean)
 		panic(1, "new_io_event: vfd [%d] hasn't been cleaned yet", vfd);
 
-	if ((c = ioe->io_callback(vfd, ioe->quiet)) <= 0)
+	if (ioe->io_callback)
 	{
-		ioe->error = -1;
-		ioe->clean = 0;
-		if (!ioe->quiet)
-		   syserr(SRV(vfd), "new_io_event: fd %d must be closed", vfd);
+		/* 
+		 * We may expect ioe->io_callback() to either call dgets_buffer
+		 * (which sets ioe->clean = 0) or to return an error (in which
+		 * case we do it ourselves right here)
+		 */
+		if ((c = ioe->io_callback(vfd, ioe->quiet)) <= 0)
+		{
+			ioe->error = -1;
+			ioe->clean = 0;
+			if (!ioe->quiet)
+			   syserr(SRV(vfd), "new_io_event: fd %d must be closed", vfd);
+
+			if (x_debug & DEBUG_INBOUND) 
+				yell("VFD [%d] FAILED [%d]", vfd, c);
+			return;
+		}
 
 		if (x_debug & DEBUG_INBOUND) 
-			yell("VFD [%d] FAILED [%d]", vfd, c);
-		return;
+			yell("VFD [%d], did [%d]", vfd, c);
 	}
+	else
+	{
+		/* 
+		 * XXX It might have been more elegant to create a passthrough
+		 * callback that just sets ioe->clean instead of having special
+		 * handling here.  Oh well.
+		 */
+		ioe->clean = 0;
+		if (x_debug & DEBUG_INBOUND) 
+			yell("VFD [%d], did pass-through", vfd);
+	}
+}
 
-	if (x_debug & DEBUG_INBOUND) 
-		yell("VFD [%d], did [%d]", vfd, c);
+static	int	is_fd_valid (int fd)
+{
+	int	retval;
+
+	/* 
+	 * This may be too conservative -- 
+	 * if F_GETFL fails, maybe it's just bad 
+	 */
+	retval = fcntl(fd, F_GETFL);
+	if (retval == -1 && errno == EBADF)
+		return 0;
+	else
+		return 1;
 }
 
 
@@ -919,32 +1027,32 @@ static	int	kdoit (Timeval *timeout)
 	{
 	    if (errno == EBADF)
 	    {
-		struct timeval t = {0, 0};
 	        int foundit = 0;
 
 		for (channel = 0; channel <= global_max_channel; channel++)
 		{
-		    /* Skip fd's that weren't in the original set */
-		    if (!FD_ISSET(channel, &readables) &&
-			!FD_ISSET(channel, &writables))
+			/* Skip fd's that weren't in the original set */
+			if (!FD_ISSET(channel, &readables) &&
+			    !FD_ISSET(channel, &writables))
 				continue;
 
-		    FD_ZERO(&working_rd);
-		    FD_SET(channel, &working_rd);
-		    errno = 0;
-		    retval = select(channel + 1, &working_rd, NULL, NULL, &t);
-		    if (retval < 0)
-		    {
-			syserr(-1, "kdoit(select): "
-					"Closing channel %d because: %s", 
-					channel, strerror(errno));
-			FD_CLR(channel, &readables);
-			FD_CLR(channel, &writables);
-			new_close(channel);
-			foundit = 1;
-		    }
+			if (!is_fd_valid(channel))
+			{
+				syserr(-1, "kdoit(select): "
+						"Closing channel %d because: %s", 
+						channel, strerror(errno));
+				FD_CLR(channel, &readables);
+				FD_CLR(channel, &writables);
+				new_close(channel);
+
+				/* If this is a python fd, we need to callback */
+				fd_is_invalid(channel);
+				foundit = 1;
+			}
 		}
 
+		/* XXX -- This is bogus -- we should do something better */
+		/* Like, maybe have everything enumerate its fd's, and start over */
 		if (!foundit)
 			panic(1, "kdoit(select): Select says I have a bad file "
 				"descriptor but I can't find it!");
